@@ -1,6 +1,9 @@
 package CatalystX::Controller::OpenSearch;
-use strict;
-use base qw( Search::OpenSearch::Server::Catalyst );
+use Moose;
+use namespace::autoclean;
+BEGIN { extends 'Catalyst::Controller'; }
+with 'Search::OpenSearch::Server::Catalyst';
+with 'Search::OpenSearch::Server';
 
 1;
 
@@ -8,17 +11,22 @@ __END__
 
 =head1 NAME
 
-CatalystX::Controller::OpenSearch - stub for Search::OpenSearch::Server::Catalyst
+CatalystX::Controller::OpenSearch - controller for Search::OpenSearch::Server::Catalyst
 
 =head1 SYNOPSIS
 
  package MyApp::Controller::Search;
- use base qw( CatalystX::Controller::OpenSearch );
+ use Moose;
+ BEGIN { extends 'CatalystX::Controller::OpenSearch'; }
  1;
 
 =head1 DESCRIPTION
 
-This class is a stub subclassing L<Search::OpenSearch::Server::Catalyst>.
+This class is a controller consuming the Roles L<Search::OpenSearch::Server::Catalyst>
+and L<Search::OpenSearch::Server>.
+
+B<NOTE> The BEGIN block noted in the SYNOPSIS is important for compatability with Moose Roles
+and Catalyst controller method attributes.
 
 =head1 AUTHOR
 
